@@ -116,14 +116,14 @@ def test_pseudo_vars():
 
 
 def test_pseudo_var_spectra():
-    data = np.array([[0,       1,       2,       3,       4],
-           [5,       6,       7,       8,       9],
-          [10,      11,      12,      13,      14],
-          [15,      16,      17,      18,      19],
-          [20,      21,      22,      23,      24]])
+    data = np.array([[0, 1, 2, 3, 4],
+                     [5, 6, 7, 8, 9],
+                     [10, 11, 12, 13, 14],
+                     [15, 16, 17, 18, 19],
+                     [20, 21, 22, 23, 24]])
 
     store_data('bins_1', data={'x': [1, 2, 3, 4, 5], 'y': data.transpose(), 'v': [10, 20, 30, 40, 50]})
-    store_data('bins_2', data={'x': [1, 2, 3, 4, 5], 'y': data.transpose()+25.0, 'v': [100, 120, 130, 140, 150]})
+    store_data('bins_2', data={'x': [1, 2, 3, 4, 5], 'y': data.transpose() + 25.0, 'v': [100, 120, 130, 140, 150]})
 
     options('bins_1', 'spec', 1)
     options('bins_1', 'yrange', [0, 200])
@@ -141,14 +141,14 @@ def test_pseudo_var_spectra():
 
 
 def test_pseudo_var_spectra_zrange():
-    data = np.array([[0,       1,       2,       3,       4],
-           [5,       6,       7,       8,       9],
-          [10,      11,      12,      13,      14],
-          [15,      16,      17,      18,      19],
-          [20,      21,      22,      23,      24]])
+    data = np.array([[0, 1, 2, 3, 4],
+                     [5, 6, 7, 8, 9],
+                     [10, 11, 12, 13, 14],
+                     [15, 16, 17, 18, 19],
+                     [20, 21, 22, 23, 24]])
 
     store_data('bins_1', data={'x': [1, 2, 3, 4, 5], 'y': data.transpose(), 'v': [10, 20, 30, 40, 50]})
-    store_data('bins_2', data={'x': [1, 2, 3, 4, 5], 'y': data.transpose()+25.0, 'v': [100, 120, 130, 140, 150]})
+    store_data('bins_2', data={'x': [1, 2, 3, 4, 5], 'y': data.transpose() + 25.0, 'v': [100, 120, 130, 140, 150]})
 
     options('bins_1', 'spec', 1)
     options('bins_1', 'yrange', [0, 200])
@@ -180,10 +180,11 @@ def test_pseudo_var_options():
 
 
 def test_errorbars():
-    cdf_to_tplot(current_directory + "/testfiles/mms1_fpi_brst_l2_dis-moms_20151016130524_v3.3.0.cdf", get_support_data=True)
+    cdf_to_tplot(current_directory + "/testfiles/mms1_fpi_brst_l2_dis-moms_20151016130524_v3.3.0.cdf",
+                 get_support_data=True)
     d = get_data('mms1_dis_numberdensity_brst')
     e = get_data('mms1_dis_numberdensity_err_brst')
-    store_data('n_with_err', data={'x': d.times, 'y': d.y, 'dy': e.y*5})
+    store_data('n_with_err', data={'x': d.times, 'y': d.y, 'dy': e.y * 5})
     tplot_options('title', 'error bars')
     tlimit(['2015-10-16 13:06:10', '2015-10-16 13:06:20'])
     tplot('n_with_err', display=False, save_png=current_directory + 'errorbars')
@@ -191,11 +192,11 @@ def test_errorbars():
 
 
 def test_spec_interp():
-    data = np.array([[0,       1,       2,       3,       4],
-           [5,       6,       7,       8,       9],
-          [10,      11,      12,      13,      14],
-          [15,      16,      17,      18,      19],
-          [20,      21,      22,      23,      24]])
+    data = np.array([[0, 1, 2, 3, 4],
+                     [5, 6, 7, 8, 9],
+                     [10, 11, 12, 13, 14],
+                     [15, 16, 17, 18, 19],
+                     [20, 21, 22, 23, 24]])
 
     store_data('bins_1', data={'x': [1, 2, 3, 4, 5], 'y': data.transpose(), 'v': [10, 20, 30, 40, 50]})
 
@@ -269,128 +270,128 @@ def test_options():
     options('mms1_dis_energyspectr_omni_brst', 'ylog', False)
     options('mms1_dis_bulkv_gse_brst', 'ylog', True)
     options('mms1_dis_numberdensity_brst', 'ylog', True)
-    tplot(panels, display=False, save_png=current_directory+'ylog')
+    tplot(panels, display=False, save_png=current_directory + 'ylog')
     options('mms1_dis_energyspectr_omni_brst', 'ylog', True)
     options('mms1_dis_bulkv_gse_brst', 'ylog', False)
     options('mms1_dis_numberdensity_brst', 'ylog', False)
 
     tplot_options('title', 'zlog')
     options('mms1_dis_energyspectr_omni_brst', 'zlog', False)
-    tplot(panels, display=False, save_png=current_directory+'zlog')
+    tplot(panels, display=False, save_png=current_directory + 'zlog')
     options('mms1_dis_energyspectr_omni_brst', 'zlog', True)
 
     tplot_options('title', 'yrange')
     options('mms1_dis_energyspectr_omni_brst', 'yrange', [1e2, 1e3])
     options('mms1_dis_bulkv_gse_brst', 'yrange', [-200, 200])
     options('mms1_dis_numberdensity_brst', 'yrange', [1, 15])
-    tplot(panels, display=False, save_png=current_directory+'yrange')
+    tplot(panels, display=False, save_png=current_directory + 'yrange')
 
     tplot_options('title', 'zrange')
     options('mms1_dis_energyspectr_omni_brst', 'zrange', [1e2, 1e7])
-    tplot(panels, display=False, save_png=current_directory+'zrange')
+    tplot(panels, display=False, save_png=current_directory + 'zrange')
     options('mms1_dis_energyspectr_omni_brst', 'zrange', [1e2, 1e8])
 
     tplot_options('title', 'ytitle')
     options('mms1_dis_energyspectr_omni_brst', 'ytitle', 'Set by test suite')
-    tplot(panels, display=False, save_png=current_directory+'ytitle')
+    tplot(panels, display=False, save_png=current_directory + 'ytitle')
     options('mms1_dis_energyspectr_omni_brst', 'ytitle', 'DES energy')
 
     tplot_options('title', 'xtitle')
     options('mms1_dis_energyspectr_omni_brst', 'xtitle', 'Set by test suite')
-    tplot(panels, display=False, save_png=current_directory+'xtitle')
+    tplot(panels, display=False, save_png=current_directory + 'xtitle')
     options('mms1_dis_energyspectr_omni_brst', 'xtitle', '')
 
     tplot_options('title', 'ztitle')
     options('mms1_dis_energyspectr_omni_brst', 'ztitle', 'Set by test suite')
-    tplot(panels, display=False, save_png=current_directory+'ztitle')
+    tplot(panels, display=False, save_png=current_directory + 'ztitle')
     options('mms1_dis_energyspectr_omni_brst', 'ztitle', 'eflux')
 
     tplot_options('title', 'ysubtitle')
     options('mms1_dis_energyspectr_omni_brst', 'ysubtitle', 'Set by test suite')
-    tplot(panels, display=False, save_png=current_directory+'ysubtitle')
+    tplot(panels, display=False, save_png=current_directory + 'ysubtitle')
     options('mms1_dis_energyspectr_omni_brst', 'ysubtitle', '')
 
     tplot_options('title', 'zsubtitle')
     options('mms1_dis_energyspectr_omni_brst', 'zsubtitle', 'Set by test suite')
-    tplot(panels, display=False, save_png=current_directory+'zsubtitle')
+    tplot(panels, display=False, save_png=current_directory + 'zsubtitle')
     options('mms1_dis_energyspectr_omni_brst', 'zsubtitle', '')
 
     tplot_options('title', 'legend_names')
     options('mms1_dis_bulkv_gse_brst', 'legend_names', ['Vx data', 'Vy data', 'Vz data'])
     options('mms1_dis_numberdensity_brst', 'legend_names', 'density')
-    tplot(panels, display=False, save_png=current_directory+'legend_names')
+    tplot(panels, display=False, save_png=current_directory + 'legend_names')
     options('mms1_dis_bulkv_gse_brst', 'legend_names', None)
     options('mms1_dis_numberdensity_brst', 'legend_names', None)
 
     tplot_options('title', 'line_style')
     options('mms1_dis_numberdensity_brst', 'line_style', 'dashed')
-    tplot(panels, display=False, save_png=current_directory+'line_style')
+    tplot(panels, display=False, save_png=current_directory + 'line_style')
     options('mms1_dis_numberdensity_brst', 'line_style', 'solid')
 
     tplot_options('title', 'line_style_multi')
     options('mms1_dis_bulkv_gse_brst', 'line_style', ['dashed', 'dotted', 'solid'])
-    tplot(panels, display=False, save_png=current_directory+'line_style_multi')
+    tplot(panels, display=False, save_png=current_directory + 'line_style_multi')
     options('mms1_dis_bulkv_gse_brst', 'line_style', 'solid')
 
     tplot_options('title', 'thickness')
     options('mms1_dis_numberdensity_brst', 'thick', 4)
     options('mms1_dis_bulkv_gse_brst', 'thick', 4)
-    tplot(panels, display=False, save_png=current_directory+'thick')
+    tplot(panels, display=False, save_png=current_directory + 'thick')
     options('mms1_dis_numberdensity_brst', 'thick', 0.5)
     options('mms1_dis_bulkv_gse_brst', 'thick', 0.5)
 
     tplot_options('title', 'thickness_multi')
     options('mms1_dis_bulkv_gse_brst', 'thick', [1, 4, 8])
-    tplot(panels, display=False, save_png=current_directory+'thickness_multi')
+    tplot(panels, display=False, save_png=current_directory + 'thickness_multi')
     options('mms1_dis_bulkv_gse_brst', 'thick', 0.5)
 
     tplot_options('title', 'alpha')
     options('mms1_dis_numberdensity_brst', 'alpha', 0.5)
     options('mms1_dis_energyspectr_omni_brst', 'alpha', 0.5)
-    tplot(panels, display=False, save_png=current_directory+'alpha')
+    tplot(panels, display=False, save_png=current_directory + 'alpha')
     options('mms1_dis_numberdensity_brst', 'alpha', 1)
     options('mms1_dis_energyspectr_omni_brst', 'alpha', 1)
 
     tplot_options('title', 'legend size')
     options('mms1_dis_bulkv_gse_brst', 'legend_names', ['Vx GSE', 'Vy GSE', 'Vz GSE'])
     options('mms1_dis_bulkv_gse_brst', 'legend_size', 20)
-    tplot(panels, display=False, save_png=current_directory+'legend_size')
+    tplot(panels, display=False, save_png=current_directory + 'legend_size')
     options('mms1_dis_bulkv_gse_brst', 'legend_size', 10)
 
     tplot_options('title', 'legend location')
     options('mms1_dis_bulkv_gse_brst', 'legend_location', 'spedas')
-    tplot(panels, display=False, save_png=current_directory+'legend_location')
+    tplot(panels, display=False, save_png=current_directory + 'legend_location')
     options('mms1_dis_bulkv_gse_brst', 'legend_location', 'best')
 
     tplot_options('title', 'legend shadow')
     options('mms1_dis_bulkv_gse_brst', 'legend_shadow', True)
-    tplot(panels, display=False, save_png=current_directory+'legend_shadow')
+    tplot(panels, display=False, save_png=current_directory + 'legend_shadow')
     options('mms1_dis_bulkv_gse_brst', 'legend_shadow', False)
 
     tplot_options('title', 'legend title')
     options('mms1_dis_bulkv_gse_brst', 'legend_title', 'legend title!')
-    tplot(panels, display=False, save_png=current_directory+'legend_title')
+    tplot(panels, display=False, save_png=current_directory + 'legend_title')
     options('mms1_dis_bulkv_gse_brst', 'legend_title', None)
 
     tplot_options('title', 'legend title size')
     options('mms1_dis_bulkv_gse_brst', 'legend_title', 'legend title!')
     options('mms1_dis_bulkv_gse_brst', 'legend_titlesize', 16)
-    tplot(panels, display=False, save_png=current_directory+'legend_title_size')
+    tplot(panels, display=False, save_png=current_directory + 'legend_title_size')
     options('mms1_dis_bulkv_gse_brst', 'legend_title', None)
 
     tplot_options('title', 'legend color')
     options('mms1_dis_bulkv_gse_brst', 'legend_color', ['blue', 'red', 'blue'])
-    tplot(panels, display=False, save_png=current_directory+'legend_color')
+    tplot(panels, display=False, save_png=current_directory + 'legend_color')
     options('mms1_dis_bulkv_gse_brst', 'legend_color', None)
 
     tplot_options('title', 'legend edge color')
     options('mms1_dis_bulkv_gse_brst', 'legend_edgecolor', 'blue')
-    tplot(panels, display=False, save_png=current_directory+'legend_edgecolor')
+    tplot(panels, display=False, save_png=current_directory + 'legend_edgecolor')
     options('mms1_dis_bulkv_gse_brst', 'legend_edgecolor', None)
 
     tplot_options('title', 'legend face color')
     options('mms1_dis_bulkv_gse_brst', 'legend_facecolor', 'blue')
-    tplot(panels, display=False, save_png=current_directory+'legend_facecolor')
+    tplot(panels, display=False, save_png=current_directory + 'legend_facecolor')
     options('mms1_dis_bulkv_gse_brst', 'legend_facecolor', None)
 
 
@@ -401,6 +402,18 @@ def test_highlight():
 
     tplot_options('title', 'highlight interval')
     pytplot.highlight('mms1_dis_bulkv_gse_brst', [1445000760.0, 1445000820.0])
-    tplot(panels, display=False, save_png=current_directory+'highlight_interval')
+    tplot(panels, display=False, save_png=current_directory + 'highlight_interval')
     pytplot.highlight('mms1_dis_bulkv_gse_brst', None)
 
+
+def test_nans_log_scale():
+    """
+    regression test for a crash when the data are all NaNs, and zlog is set
+    """
+    tplot_options('title', 'NaNs zlog regression test - should be empty')
+    y = np.zeros((5, 3))
+    y[:] = np.nan
+    store_data('test_spec_nan', data={'x': [1, 2, 3, 4, 5], 'y': y, 'v': [6, 7, 8]})
+    options('test_spec_nan', 'spec', True)
+    options('test_spec_nan', 'zlog', True)
+    tplot('test_spec_nan', display=False, save_png=current_directory + 'nans_zlog_regression')
\ No newline at end of file
